@@ -29,9 +29,9 @@
  *
  *  The above copyright notice and this permission notice shall be included in
  *  all copies of the Software and its Copyright notices. In addition publicly
- *  documented acknowledgement must be given that this software has been used if no
+ *  documented acknowledgment must be given that this software has been used if no
  *  source code of this software is made available publicly. This includes
- *  acknowledgements in either Copyright notices, Manuals, Publicity and Marketing
+ *  acknowledgments in either Copyright notices, Manuals, Publicity and Marketing
  *  documents or any documentation provided with any product containing this
  *  software. This License does not apply to any software that links to the
  *  libraries provided by this software (statically or dynamically), but only to
@@ -92,8 +92,8 @@
 /**
  * @brief Retrieves an instance of a string for use in a program.
  *
- * @param   str The string to retrieve an instance of.
- * @param   slen The string size (<= strlen(str)).
+ * @param[in] str The string to retrieve an instance of.
+ * @param[in] slen The string size (<= strlen(str)).
  * @return  A pointer to an instance of the string on success,
  *          @c NULL on failure.
  *
@@ -109,12 +109,12 @@
  *
  * @see eina_ustringshare_add()
  */
-EAPI const Eina_Unicode *eina_ustringshare_add_length(const Eina_Unicode *str, unsigned int slen) EINA_WARN_UNUSED_RESULT;
+EINA_API const Eina_Unicode *eina_ustringshare_add_length(const Eina_Unicode *str, unsigned int slen) EINA_WARN_UNUSED_RESULT;
 
 /**
  * @brief Retrieves an instance of a string for use in a program.
  *
- * @param   str The NULL-terminated string to retrieve an instance of.
+ * @param[in] str The NULL-terminated string to retrieve an instance of.
  * @return  A pointer to an instance of the string on success,
  *          @c NULL on failure.
  *
@@ -130,12 +130,12 @@ EAPI const Eina_Unicode *eina_ustringshare_add_length(const Eina_Unicode *str, u
  *
  * @see eina_ustringshare_add_length()
  */
-EAPI const Eina_Unicode *eina_ustringshare_add(const Eina_Unicode *str) EINA_WARN_UNUSED_RESULT;
+EINA_API const Eina_Unicode *eina_ustringshare_add(const Eina_Unicode *str) EINA_WARN_UNUSED_RESULT;
 
 /**
  * @brief Increments references of the given shared string.
  *
- * @param str The shared string.
+ * @param[in] str The shared string.
  * @return    A pointer to an instance of the string on success,
  *            @c NULL on failure.
  *
@@ -146,12 +146,12 @@ EAPI const Eina_Unicode *eina_ustringshare_add(const Eina_Unicode *str) EINA_WAR
  *
  * There is no unref since this is the work of eina_ustringshare_del().
  */
-EAPI const Eina_Unicode *eina_ustringshare_ref(const Eina_Unicode *str);
+EINA_API const Eina_Unicode *eina_ustringshare_ref(const Eina_Unicode *str);
 
 /**
  * @brief Notes that the given string has lost an instance.
  *
- * @param str String The given string.
+ * @param[in] str String The given string.
  *
  * This function decreases the reference counter associated to @p str
  * if it exists. If that counter reaches 0, the memory associated to
@@ -161,13 +161,14 @@ EAPI const Eina_Unicode *eina_ustringshare_ref(const Eina_Unicode *str);
  * @note If the given pointer is not shared, bad things will happen, likely a
  * segmentation fault.
  */
-EAPI void                eina_ustringshare_del(const Eina_Unicode *str);
+EINA_API void                eina_ustringshare_del(const Eina_Unicode *str);
 
 /**
  * @brief Notes that the given string @b must be shared.
  *
- * @param str The shared string to know the length. It is safe to
+ * @param[in] str The shared string to know the length. It is safe to
  *        give @c NULL, in that case @c -1 is returned.
+ * @return The length of a shared string.
  *
  * This function is a cheap way to known the length of a shared
  * string.
@@ -175,7 +176,7 @@ EAPI void                eina_ustringshare_del(const Eina_Unicode *str);
  * @note If the given pointer is not shared, bad things will happen, likely a
  * segmentation fault. If in doubt, try strlen().
  */
-EAPI int                 eina_ustringshare_strlen(const Eina_Unicode *str) EINA_PURE EINA_WARN_UNUSED_RESULT;
+EINA_API int                 eina_ustringshare_strlen(const Eina_Unicode *str) EINA_PURE EINA_WARN_UNUSED_RESULT;
 
 /**
  * @brief Dumps the contents of the share_common.
@@ -183,7 +184,7 @@ EAPI int                 eina_ustringshare_strlen(const Eina_Unicode *str) EINA_
  * This function dumps all strings in the share_common to stdout with a
  * DDD: prefix per line and a memory usage summary.
  */
-EAPI void                eina_ustringshare_dump(void);
+EINA_API void                eina_ustringshare_dump(void);
 
 static inline Eina_Bool  eina_ustringshare_replace(const Eina_Unicode **p_str, const Eina_Unicode *news) EINA_ARG_NONNULL(1);
 static inline Eina_Bool  eina_ustringshare_replace_length(const Eina_Unicode **p_str, const Eina_Unicode *news, unsigned int slen) EINA_ARG_NONNULL(1);
